@@ -110,6 +110,8 @@ class JSONDataSet(AbstractVersionedDataSet):
         protocol, path = get_protocol_and_path(filepath, version)
 
         self._protocol = protocol
+        if protocol == "file":
+            _fs_args.setdefault("auto_mkdir", True)
         self._fs = fsspec.filesystem(self._protocol, **_credentials, **_fs_args)
 
         super().__init__(
@@ -124,7 +126,6 @@ class JSONDataSet(AbstractVersionedDataSet):
         if save_args is not None:
             self._save_args.update(save_args)
 
-        _fs_open_args_load.setdefault("mode", "r")
         _fs_open_args_save.setdefault("mode", "w")
         self._fs_open_args_load = _fs_open_args_load
         self._fs_open_args_save = _fs_open_args_save
