@@ -146,9 +146,9 @@ class KedroHdfsInsecureClient(InsecureClient):
                 if fnmatch(dpath, pattern):
                     matched.add(dpath)
                 matched |= set(
-                    "{}/{}".format(dpath, fname)
+                    f"{dpath}/{fname}"
                     for fname in fnames
-                    if fnmatch("{}/{}".format(dpath, fname), pattern)
+                    if fnmatch(f"{dpath}/{fname}", pattern)
                 )
         except HdfsError:  # pragma: no cover
             # HdfsError is raised by `self.walk()` if prefix does not exist in HDFS.
@@ -225,10 +225,9 @@ class SparkDataSet(AbstractVersionedDataSet):
                 None, the latest version will be loaded. If its ``save``
                 attribute is None, save version will be autogenerated.
             credentials: Credentials to access the S3 bucket, such as
-                ``aws_access_key_id``, ``aws_secret_access_key``, if ``filepath``
-                prefix is ``s3a://`` or ``s3n://``. Optional keyword arguments passed to
-                ``hdfs.client.InsecureClient`` if ``filepath`` prefix is ``hdfs://``.
-                Ignored otherwise.
+                ``key``, ``secret``, if ``filepath`` prefix is ``s3a://`` or ``s3n://``.
+                Optional keyword arguments passed to ``hdfs.client.InsecureClient``
+                if ``filepath`` prefix is ``hdfs://``. Ignored otherwise.
         """
         credentials = deepcopy(credentials) or {}
         fs_prefix, filepath = _split_filepath(filepath)
@@ -242,7 +241,7 @@ class SparkDataSet(AbstractVersionedDataSet):
                     "please consider switching to `s3a`",
                     DeprecationWarning,
                 )
-            _s3 = S3FileSystem(client_kwargs=credentials)
+            _s3 = S3FileSystem(**credentials)
             exists_function = _s3.exists
             glob_function = partial(_s3.glob, refresh=True)
             path = PurePosixPath(filepath)
@@ -292,7 +291,7 @@ class SparkDataSet(AbstractVersionedDataSet):
 
     def __getstate__(self):
         # SparkDataSet cannot be used with ParallelRunner
-        raise AttributeError("{} cannot be serialized!".format(self.__class__.__name__))
+        raise AttributeError(f"{self.__class__.__name__} cannot be serialized!")
 
     def _describe(self) -> Dict[str, Any]:
         return dict(
