@@ -33,9 +33,6 @@ This module implements commands available from the kedro CLI.
 import importlib
 import os
 import re
-import shutil
-import sys
-import traceback
 import warnings
 import webbrowser
 from collections import defaultdict
@@ -44,6 +41,7 @@ from pathlib import Path
 from typing import Any, Callable, Dict, List
 
 import click
+import git
 import pkg_resources
 import yaml
 
@@ -52,53 +50,47 @@ from kedro import __version__ as version
 from kedro.framework.cli.utils import (
     CommandCollection,
     KedroCliError,
+    _add_src_to_path,
     _clean_pycache,
     _filter_deprecation_warnings,
+    command_with_verbosity,
 )
-from kedro.framework.context import load_context
+from kedro.framework.context.context import load_context
+from kedro.framework.startup import _get_project_metadata, _is_project
 
 KEDRO_PATH = Path(kedro.__file__).parent
 TEMPLATE_PATH = KEDRO_PATH / "templates" / "project"
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 
-_VERBOSE = True
-
-LOGO = r"""
+LOGO = rf"""
  _            _
 | | _____  __| |_ __ ___
 | |/ / _ \/ _` | '__/ _ \
 |   <  __/ (_| | | | (_) |
 |_|\_\___|\__,_|_|  \___/
-v{}
-""".format(
-    version
-)
+v{version}
+"""
 
+_STARTERS_REPO = "git+https://github.com/quantumblacklabs/kedro-starters.git"
 _STARTER_ALIASES = {
-    "pandas-iris": "git+https://github.com/quantumblacklabs/kedro-starter-pandas-iris.git",
-    "pyspark": "git+https://github.com/quantumblacklabs/kedro-starter-pyspark.git",
-    "pyspark-iris": "git+https://github.com/quantumblacklabs/kedro-starter-pyspark-iris.git",
-    "spaceflights": "git+https://github.com/quantumblacklabs/kedro-starter-spaceflights.git",
+    "mini-kedro",
+    "pandas-iris",
+    "pyspark",
+    "pyspark-iris",
+    "spaceflights",
 }
 
 
 @click.group(context_settings=CONTEXT_SETTINGS, name="Kedro")
 @click.version_option(version, "--version", "-V", help="Show version and exit")
-@click.option(
-    "--verbose",
-    "-v",
-    is_flag=True,
-    help="See extensive logging and error stack traces.",
-)
-def cli(verbose):
+def cli():
     """Kedro is a CLI for creating and using Kedro projects
     For more information, type ``kedro info``.
 
     When inside a Kedro project (created with `kedro new`) commands from
-    the project's `kedro_cli.py` file will also be available here.
+    the project's `cli.py` file will also be available here.
     """
-    global _VERBOSE  # pylint: disable=global-statement
-    _VERBOSE = verbose
+    pass
 
 
 ENTRY_POINT_GROUPS = {
@@ -139,7 +131,7 @@ def info():
         click.echo("No plugins installed")
 
 
-@cli.command(short_help="Create a new kedro project.")
+@command_with_verbosity(cli, short_help="Create a new kedro project.")
 @click.option(
     "--config",
     "-c",
@@ -155,7 +147,13 @@ def info():
 @click.option(
     "--checkout", help="A tag, branch or commit to checkout in the starter repository."
 )
-def new(config, starter_name, checkout):
+@click.option(
+    "--directory",
+    help="An optional directory inside the repository where the starter resides.",
+)
+def new(
+    config, starter_name, checkout, directory, **kwargs
+):  # pylint: disable=unused-argument
     """Create a new kedro project, either interactively or from a
     configuration file.
 
@@ -183,7 +181,7 @@ def new(config, starter_name, checkout):
 
     * ``config.yml`` - The configuration YAML must contain at the top level
                     the above parameters (project_name, repo_name,
-                    python_package, include_example) and output_dir - the
+                    python_package) and output_dir - the
                     parent directory for the new project directory.
 
     \b
@@ -197,23 +195,36 @@ def new(config, starter_name, checkout):
     Create a new project from a starter template and a particular tag, branch or commit
     in the starter repository.
 
+    \b
+    ``kedro new --starter <starter> --directory <directory>``
+    Create a new project from a starter repository and a directory within the location.
+    Useful when you have multiple starters in the same repository.
     """
     if checkout and not starter_name:
         raise KedroCliError("Cannot use the --checkout flag without a --starter value.")
 
-    if starter_name:
-        template_path = _STARTER_ALIASES.get(starter_name, starter_name)
-        should_prompt_for_example = False
+    if directory and not starter_name:
+        raise KedroCliError(
+            "Cannot use the --directory flag without a --starter value."
+        )
+
+    if starter_name in _STARTER_ALIASES:
+        if directory:
+            raise KedroCliError(
+                "Cannot use the --directory flag with a --starter alias."
+            )
+        template_path = _STARTERS_REPO
+        directory = starter_name
+    elif starter_name is not None:
+        template_path = starter_name
     else:
         template_path = TEMPLATE_PATH
-        should_prompt_for_example = True
 
     _create_project(
         config_path=config,
-        verbose=_VERBOSE,
         template_path=template_path,
-        should_prompt_for_example=should_prompt_for_example,
         checkout=checkout,
+        directory=directory,
     )
 
 
@@ -238,87 +249,98 @@ def starter():
 @starter.command("list")
 def list_starters():
     """List all official project starters available."""
-
-    def _get_clickable_link(git_link):
-        prefix = re.escape("git+")
-        return re.sub(rf"^{prefix}", "", git_link)
-
+    repo_url = _STARTERS_REPO.replace("git+", "").replace(
+        ".git", "/tree/master/{alias}"
+    )
     output = [
-        {alias: _get_clickable_link(url)}
-        for alias, url in sorted(_STARTER_ALIASES.items())
+        {alias: repo_url.format(alias=alias)} for alias in sorted(_STARTER_ALIASES)
     ]
     click.echo(yaml.safe_dump(output))
 
 
 def _create_project(
     config_path: str,
-    verbose: bool,
     template_path: Path = TEMPLATE_PATH,
-    should_prompt_for_example: bool = True,
     checkout: str = None,
+    directory: str = None,
 ):
     """Implementation of the kedro new cli command.
 
     Args:
         config_path: In non-interactive mode, the path of the config.yml which
             should contain the project_name, output_dir and repo_name.
-        verbose: Extensive debug terminal logs.
         template_path: The path to the cookiecutter template to create the project.
             It could either be a local directory or a remote VCS repository
             supported by cookiecutter. For more details, please see:
             https://cookiecutter.readthedocs.io/en/latest/usage.html#generate-your-project
-        should_prompt_for_example: Whether to display a prompt to generate an example pipeline.
-            N.B.: this should only be here until the start project is complete and the
-            starters with example are all located in public repositories.
         checkout: The tag, branch or commit in the starter repository to checkout.
             Maps directly to cookiecutter's --checkout argument.
-            If the value is invalid, cookiecutter will use the default branch.
+            If the value is not provided, cookiecutter will use the installed Kedro version
+            by default.
+        directory: The directory of a specific starter inside a repository containing
+            multiple starters. Map directly to cookiecutter's --directory argument.
+            https://cookiecutter.readthedocs.io/en/1.7.2/advanced/directories.html
+    Raises:
+        KedroCliError: If it fails to generate a project.
     """
     with _filter_deprecation_warnings():
         # pylint: disable=import-outside-toplevel
-        from cookiecutter.exceptions import RepositoryNotFound
+        from cookiecutter.exceptions import RepositoryCloneFailed, RepositoryNotFound
         from cookiecutter.main import cookiecutter  # for performance reasons
 
     try:
         if config_path:
-            config = _parse_config(config_path, verbose)
+            config = _parse_config(config_path)
             config = _check_config_ok(config_path, config)
         else:
-            config = _get_config_from_prompts(should_prompt_for_example)
+            config = _get_config_from_prompts()
         config.setdefault("kedro_version", version)
 
-        result_path = Path(
-            cookiecutter(
-                str(template_path),
-                output_dir=config["output_dir"],
-                no_input=True,
-                extra_context=config,
-                checkout=checkout,
-            )
+        checkout = checkout or version
+        cookiecutter_args = dict(
+            output_dir=config["output_dir"],
+            no_input=True,
+            extra_context=config,
+            checkout=checkout,
         )
-
-        # If user was prompted to generate an example but chooses not to,
-        # Remove all placeholder directories.
-        if should_prompt_for_example and not config["include_example"]:
-            (result_path / "data" / "01_raw" / "iris.csv").unlink()
-
-            pipelines_dir = result_path / "src" / config["python_package"] / "pipelines"
-
-            for dir_path in [
-                pipelines_dir / "data_engineering",
-                pipelines_dir / "data_science",
-            ]:
-                shutil.rmtree(str(dir_path))
-
+        if directory:
+            cookiecutter_args["directory"] = directory
+        result_path = Path(cookiecutter(str(template_path), **cookiecutter_args))
         _clean_pycache(result_path)
         _print_kedro_new_success_message(result_path)
-    except click.exceptions.Abort:  # pragma: no cover
-        _handle_exception("User interrupt.")
-    except RepositoryNotFound:
-        _handle_exception(f"Kedro project template not found at {template_path}")
+    except click.exceptions.Abort as exc:  # pragma: no cover
+        raise KedroCliError("User interrupt.") from exc
+    except RepositoryNotFound as exc:
+        raise KedroCliError(
+            f"Kedro project template not found at {template_path}"
+        ) from exc
+    except RepositoryCloneFailed as exc:
+        error_message = (
+            f"Kedro project template not found at {template_path} with tag {checkout}."
+        )
+        tags = _get_available_tags(str(template_path).replace("git+", ""))
+        if tags:
+            error_message += (
+                f" The following tags are available: {', '.join(tags.__iter__())}"
+            )
+        raise KedroCliError(error_message) from exc
     # we don't want the user to see a stack trace on the cli
-    except Exception:  # pylint: disable=broad-except
-        _handle_exception("Failed to generate project.")
+    except Exception as exc:
+        raise KedroCliError("Failed to generate project.") from exc
+
+
+def _get_available_tags(template_path: str) -> List:
+    try:
+        tags = git.cmd.Git().ls_remote("--tags", str(template_path)).split("\n")
+
+        unique_tags = {tag.split("/")[-1].replace("^{}", "") for tag in tags}
+        # Remove git ref "^{}" and duplicates. For example,
+        # tags: ['/tags/version', '/tags/version^{}']
+        # unique_tags: {'version'}
+
+    except git.GitCommandError:
+        return []
+    return sorted(unique_tags)
 
 
 def _get_user_input(
@@ -347,12 +369,9 @@ def _get_user_input(
         return value
 
 
-def _get_config_from_prompts(should_prompt_for_example: bool = True) -> Dict:
+def _get_config_from_prompts() -> Dict:
     """Ask user to provide necessary inputs.
 
-    Args:
-        should_prompt_for_example: Whether to include a prompt for example.
-
     Returns:
         Resulting config dictionary.
 
@@ -399,32 +418,19 @@ def _get_config_from_prompts(should_prompt_for_example: bool = True) -> Dict:
         pkg_name_prompt, default=default_pkg_name, check_input=_assert_pkg_name_ok
     )
 
-    # option for whether iris example code is included in the project
-    if should_prompt_for_example:
-        code_example_prompt = _get_prompt_text(
-            "Generate Example Pipeline:",
-            "Do you want to generate an example pipeline in your project?",
-            "Good for first-time users. (default=N)",
-        )
-        include_example = click.confirm(code_example_prompt, default=False)
-    else:
-        include_example = False
-
     return {
         "output_dir": output_dir,
         "project_name": project_name,
         "repo_name": repo_name,
         "python_package": python_package,
-        "include_example": include_example,
     }
 
 
-def _parse_config(config_path: str, verbose: bool) -> Dict:
+def _parse_config(config_path: str) -> Dict:
     """Parse the config YAML from its path.
 
     Args:
         config_path: The path of the config.yml file.
-        verbose: Print the config contents.
 
     Raises:
         Exception: If the file cannot be parsed.
@@ -437,7 +443,7 @@ def _parse_config(config_path: str, verbose: bool) -> Dict:
         with open(config_path, "r") as config_file:
             config = yaml.safe_load(config_file)
 
-        if verbose:
+        if KedroCliError.VERBOSE_ERROR:
             click.echo(config_path + ":")
             click.echo(yaml.dump(config, default_flow_style=False))
 
@@ -482,7 +488,6 @@ def _check_config_ok(config_path: str, config: Dict[str, Any]) -> Dict[str, Any]
     _assert_output_dir_ok(config["output_dir"])
     _assert_repo_name_ok(config["repo_name"])
     _assert_pkg_name_ok(config["python_package"])
-    _assert_include_example_ok(config["include_example"])
     return config
 
 
@@ -504,9 +509,9 @@ def _assert_output_dir_ok(output_dir: str):
     """
     if not os.path.exists(output_dir):
         message = (
-            "`{}` is not a valid output directory. "
-            "It must be a relative or absolute path "
-            "to an existing directory.".format(output_dir)
+            f"`{output_dir}` is not a valid output directory. "
+            f"It must be a relative or absolute path "
+            f"to an existing directory."
         )
         raise KedroCliError(message)
 
@@ -521,7 +526,7 @@ def _assert_pkg_name_ok(pkg_name: str):
         KedroCliError: If package name violates the requirements.
     """
 
-    base_message = "`{}` is not a valid Python package name.".format(pkg_name)
+    base_message = f"`{pkg_name}` is not a valid Python package name."
     if not re.match(r"^[a-zA-Z_]", pkg_name):
         message = base_message + " It must start with a letter or underscore."
         raise KedroCliError(message)
@@ -538,18 +543,9 @@ def _assert_pkg_name_ok(pkg_name: str):
 def _assert_repo_name_ok(repo_name):
     if not re.match(r"^\w+(-*\w+)*$", repo_name):
         message = (
-            "`{}` is not a valid repository name. It must contain "
-            "only word symbols and/or hyphens, must also start and "
-            "end with alphanumeric symbol.".format(repo_name)
-        )
-        raise KedroCliError(message)
-
-
-def _assert_include_example_ok(include_example):
-    if not isinstance(include_example, bool):
-        message = (
-            "`{}` value for `include_example` is invalid. It must be a boolean value "
-            "True or False.".format(include_example)
+            f"`{repo_name}` is not a valid repository name. It must contain "
+            f"only word symbols and/or hyphens, must also start and "
+            f"end with alphanumeric symbol."
         )
         raise KedroCliError(message)
 
@@ -575,9 +571,7 @@ def _show_example_config():
 
 def _print_kedro_new_success_message(result):
     click.secho(
-        "\nChange directory to the project generated in {}".format(
-            str(result.resolve())
-        ),
+        f"\nChange directory to the project generated in {result.resolve()}",
         fg="green",
     )
     click.secho(
@@ -593,7 +587,7 @@ def _get_prompt_text(title, *text, start: str = "\n"):
     title = click.style(title + "\n" + "=" * len(title), bold=True)
     prompt_lines = [title] + list(text)
     prompt_text = "\n".join(str(line).strip() for line in prompt_lines)
-    return "{}{}\n".format(start, prompt_text)
+    return f"{start}{prompt_text}\n"
 
 
 def get_project_context(
@@ -617,48 +611,18 @@ def get_project_context(
         KedroCliError: When the key is not found and the default value was not
             specified.
     """
-
-    def _deprecation_msg(key):
-        msg_dict = {
-            "get_config": ["config_loader", "ConfigLoader"],
-            "create_catalog": ["catalog", "DataCatalog"],
-            "create_pipeline": ["pipeline", "Pipeline"],
-            "template_version": ["project_version", None],
-            "project_name": ["project_name", None],
-            "project_path": ["project_path", None],
-        }
-        attr, obj_name = msg_dict[key]
-        msg = '`get_project_context("{}")` is now deprecated. '.format(key)
-        if obj_name:
-            msg += (
-                "This is still returning a function that returns `{}` "
-                "instance, however passed arguments have no effect anymore "
-                "since Kedro 0.15.0. ".format(obj_name)
-            )
-        msg += (
-            "Please get `KedroContext` instance by calling `get_project_context()` "
-            "and use its `{}` attribute.".format(attr)
-        )
-
-        return msg
-
+    warnings.warn(
+        "`get_project_context` is now deprecated and will be removed in Kedro 0.18.0. "
+        "Please use `KedroSession.load_context()` to access the "
+        "`KedroContext` object. For more information, please visit "
+        "https://kedro.readthedocs.io/en/stable/04_kedro_project_setup/03_session.html",
+        DeprecationWarning,
+    )
     project_path = project_path or Path.cwd()
     context = load_context(project_path, **kwargs)
     # Dictionary to be compatible with existing Plugins. Future plugins should
     # retrieve necessary Kedro project properties from context
-    value = {
-        "context": context,
-        "get_config": lambda project_path, env=None, **kw: context.config_loader,
-        "create_catalog": lambda config, **kw: context.catalog,
-        "create_pipeline": lambda **kw: context.pipeline,
-        "template_version": context.project_version,
-        "project_name": context.project_name,
-        "project_path": context.project_path,
-        "verbose": _VERBOSE,
-    }[key]
-
-    if key not in ("verbose", "context"):
-        warnings.warn(_deprecation_msg(key), DeprecationWarning)
+    value = {"context": context, "verbose": KedroCliError.VERBOSE_ERROR}[key]
 
     return deepcopy(value)
 
@@ -670,7 +634,7 @@ def load_entry_points(name: str) -> List[str]:
         name: The key value specified in ENTRY_POINT_GROUPS.
 
     Raises:
-        Exception: If loading an entry point failed.
+        KedroCliError: If loading an entry point failed.
 
     Returns:
         List of entry point commands.
@@ -681,8 +645,8 @@ def load_entry_points(name: str) -> List[str]:
     for entry_point in entry_points:
         try:
             entry_point_commands.append(entry_point.load())
-        except Exception:  # pylint: disable=broad-except
-            _handle_exception(f"Loading {name} commands from {entry_point}", end=False)
+        except Exception as exc:
+            raise KedroCliError(f"Loading {name} commands from {entry_point}") from exc
     return entry_point_commands
 
 
@@ -692,12 +656,12 @@ def _init_plugins():
         try:
             init_hook = entry_point.load()
             init_hook()
-        except Exception:  # pylint: disable=broad-except
-            _handle_exception(f"Initializing {entry_point}", end=False)
+        except Exception as exc:
+            raise KedroCliError(f"Initializing {entry_point}") from exc
 
 
 def main():  # pragma: no cover
-    """Main entry point, look for a `kedro_cli.py` and if found add its
+    """Main entry point, look for a `cli.py` and if found add its
     commands to `kedro`'s then invoke the cli.
     """
     _init_plugins()
@@ -705,40 +669,31 @@ def main():  # pragma: no cover
     global_groups = [cli]
     global_groups.extend(load_entry_points("global"))
     project_groups = []
+    cli_context = dict()
 
-    # load project commands from kedro_cli.py
     path = Path.cwd()
-    kedro_cli_path = path / "kedro_cli.py"
+    if _is_project(path):
+        # load project commands from cli.py
+        metadata = _get_project_metadata(path)
+        cli_context = dict(obj=metadata)
+        _add_src_to_path(metadata.source_dir, path)
+
+        project_groups.extend(load_entry_points("project"))
+        package_name = metadata.package_name
 
-    if kedro_cli_path.exists():
         try:
-            sys.path.append(str(path))
-            kedro_cli = importlib.import_module("kedro_cli")
-            project_groups.extend(load_entry_points("project"))
-            project_groups.append(kedro_cli.cli)
-        except Exception:  # pylint: disable=broad-except
-            _handle_exception(f"Cannot load commands from {kedro_cli_path}")
+            project_cli = importlib.import_module(f"{package_name}.cli")
+            project_groups.append(project_cli.cli)
+        except Exception as exc:
+            raise KedroCliError(
+                f"Cannot load commands from {package_name}.cli"
+            ) from exc
+
     cli_collection = CommandCollection(
         ("Global commands", global_groups),
         ("Project specific commands", project_groups),
     )
-    cli_collection()
-
-
-def _handle_exception(msg, end=True):
-    """Pretty print the current exception then exit."""
-    if _VERBOSE:
-        click.secho(traceback.format_exc(), nl=False, fg="yellow")
-    else:
-        etype, value, _ = sys.exc_info()
-        click.secho(
-            "".join(traceback.format_exception_only(etype, value))
-            + "Run with --verbose to see the full exception",
-            fg="yellow",
-        )
-    if end:
-        raise KedroCliError(msg)
-    click.secho("Error: " + msg, fg="red")  # pragma: no cover
+    cli_collection(**cli_context)
 
 
 if __name__ == "__main__":  # pragma: no cover
