@@ -32,7 +32,4 @@ project context.
 
 from .context import KedroContext  # NOQA
 from .context import KedroContextError  # NOQA
-from .context import get_static_project_data  # NOQA
 from .context import load_context  # NOQA
-from .context import load_package_context  # NOQA
-from .context import validate_source_path  # NOQA
