@@ -33,12 +33,18 @@ from typing import Any, Callable
 
 
 class AbstractTransformer(abc.ABC):
-    """``AbstractTransformer`` is the base class for all transformer implementations.
+    """ Transformers will be deprecated in Kedro 0.18.0 in favour of the Dataset Hooks.
+
+    ``AbstractTransformer`` is the base class for all transformer implementations.
     All transformer implementations should extend this abstract class
     and customise the `load` and `save` methods where appropriate."""
 
     def load(self, data_set_name: str, load: Callable[[], Any]) -> Any:
-        """Wrap the loading of a dataset.
+        """
+        This method will be deprecated in Kedro 0.18.0 in favour of the Dataset Hooks
+        `before_dataset_loaded` and `after_dataset_loaded`.
+
+        Wrap the loading of a dataset.
         Call ``load`` to get the data from the data set / next transformer.
 
         Args:
@@ -53,7 +59,11 @@ class AbstractTransformer(abc.ABC):
         return load()
 
     def save(self, data_set_name: str, save: Callable[[Any], None], data: Any) -> None:
-        """ Wrap the saving of a dataset.
+        """
+        This method will be deprecated in Kedro 0.18.0 in favour of the Dataset Hooks
+        `before_dataset_saved` and `after_dataset_saved`.
+
+        Wrap the saving of a dataset.
         Call ``save`` to pass the data to the  data set / next transformer.
 
         Args:
